DynTensor

Struct DynTensor 

pub struct DynTensor<B: Backend> { /* private fields */ }
A dynamic Tensor wrapper that can be sliced.

Implementations

Source

impl<B: Backend> DynTensor<B>

pub fn new<const R: usize, K>(tensor: Tensor<B, R, K>) -> Self
where K: BasicOps<B> + 'static,

Create a new TensorStub from a tensor.

pub fn rank(&self) -> usize

Get the tensor rank.

pub fn shape(&self) -> Shape

Get the tensor shape.

pub fn num_elements(&self) -> usize

Get the number of elements in the tensor.

pub fn size_estimate(&self) -> usize

Returns the size estimate of the tensor in bytes.

This is self.dtype().size() * self.num_elements().

pub fn dtype(&self) -> DType

Get the tensor data type.

pub fn kind(&self) -> KindFlag

Get the tensor kind.

pub fn device(&self) -> B::Device

Get the tensor device.

pub fn downcast_clone<const R: usize, K>(&self) -> Option<Tensor<B, R, K>>
where K: 'static + BasicOps<B>,

Downcasts the tensor to a specific rank and kind.

Result
  • Some(Tensor<B, R, K>): if the params are correct,
  • None: otherwise.
pub fn unwrap_clone<const R: usize, K>(&self) -> Tensor<B, R, K>
where K: 'static + BasicOps<B>,

Downcasts to a static tensor.

Result
  • the static tensor: if the params are correct,
Panics

If the types are incorrect.

pub fn slice<const R: usize, S>(self, slices: S) -> Result<Self, DynTensorError>
where S: SliceArg<R>,

Slice the stub tensor.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • slices: a SliceArg<R>.
Result
  • Ok(DynTensor): the sliced tensor.
  • Err(DynTensorError): an error.
pub fn slice_dyn(self, slices: &[Slice]) -> Result<Self, DynTensorError>

A dynamic version of DynTensor::slice.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • slices: a dynamic slice of Slice.
Result
  • Ok(DynTensor): the sliced tensor.
  • Err(DynTensorError): an error.
pub fn slice_assign<const R2: usize, S, V>( self, slices: S, values: V, ) -> Result<Self, DynTensorError>
where S: SliceArg<R2>, V: ValuesArg<B>,

Assign values to a slice.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • slices: a SlicesArg<R2>.
  • values: a coercible value; see ValuesArg.
Result
  • Ok(DynTensor): a converted tensor.
  • Err(DynTensorError): an error.
pub fn slice_assign_dyn<V>( self, slices: &[Slice], values: V, ) -> Result<Self, DynTensorError>
where V: ValuesArg<B>,

Dynamic slice rank version of DynTensor::slice_assign.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • slices: a dynamic slice of Slice.
  • values: a coercible value; see ValuesArg.
Result
  • Ok(DynTensor): a converted tensor.
  • Err(DynTensorError): an error.
pub fn flatten(self) -> Result<Self, DynTensorError>

Flatten the tensor.

Dispatches via rank_dispatch::dispatch_rank.

Result
  • Ok(DynTensor): a flattened (rank=1) tensor.
  • Err(DynTensorError): an error.
pub fn cast(self, dtype: DType) -> Result<Self, DynTensorError>

Cast the tensor.

Auto-converts kind if necessary.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • dtype: the target data type.
Result
  • Ok(DynTensor): a converted tensor.
  • Err(DynTensorError): an error.
pub fn to_device(self, device: &B::Device) -> Result<Self, DynTensorError>

Move the tensor to the given device.

Moving to the same device is an inexpensive no-op.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • device: the target device.
Result
  • Ok(DynTensor<B>): the moved tensor.
  • Err(DynTensorError): an error.
pub fn from_data( data: TensorData, device: &B::Device, ) -> Result<Self, DynTensorError>

Convert a TensorData to a DynTensor.

Dispatches via rank_dispatch::dispatch_rank.

Arguments
  • data: source TensorData.
  • device: the target device.
Result
  • Ok(DynTensor<B>): the converted tensor.
  • Err(DynTensorError): an error.
pub fn into_data(self) -> Result<TensorData, DynTensorError>

Convert the tensor to a TensorData.

Dispatches via rank_dispatch::dispatch_rank.

Result
  • Ok(TensorData): the converted data.
  • Err(DynTensorError): an error.
pub fn to_data(self) -> Result<TensorData, DynTensorError>

Convert the tensor to a TensorData.

Dispatches via rank_dispatch::dispatch_rank.

Result
  • Ok(TensorData): the converted data.
  • Err(DynTensorError): an error.